%ifarch %{arm} %{ix86} x86_64
%global has_luajit 1
%endif

%define _default_patch_fuzz 1
%define Werror_cflags %nil

%global __requires_exclude_from  %{_docdir}/%{name}

# Csound is really dumb about 64-bit
%ifarch x86_64 ia64
%define build64bit 1
%define install64bit --word64
%define useDouble 1
%else
%define build64bit 0
%define install64bit %{nil}
%define useDouble 0
%endif

%define build_java 0
%{?_with_java: %{expand: %%global build_java 1}}

Summary:	A sound synthesis language and library
Name:		csound
Version:	6.06
Release:	%mkrel 4
License:	LGPLv2+
Group:		Sound/Utilities
URL:		http://csound.sourceforge.net/

Source0:	http://downloads.sourceforge.net/csound/Csound%{version}.tar.gz
Source2:	http://downloads.sourceforge.net/csound/manual_src.tar.gz

# Some patches taken from the Fedora .spec - thanks!
# Put plugins in _libdir/csound/plugins on all platforms
Patch0:  %{name}-6.03-64-bit-plugin-path.patch
# Rename some binaries to avoid name conflicts
Patch1:  %{name}-6.03-fix-conflicts.patch
# Default to using pulseaudio instead of portaudio
Patch2:  %{name}-6.03-default-pulse.patch
# Do not use SSE2 on non-x86_64 platforms
Patch3:  %{name}-6.03-sse2.patch
# Adapt to the way portmidi/porttime is packaged in Fedora
Patch4:  %{name}-6.03-porttime.patch
# Use xdg-open to open a browser to view the manual
Patch5:  %{name}-6.03-xdg-open.patch
# fix build with latest boost (from upstream)
Patch6:	 csound-6.06-orc-count.patch
Patch7:	 csound-6.06-boost-name-clash.patch

BuildRequires:	cmake
BuildRequires:	swig
BuildRequires:	libsndfile-devel
BuildRequires:	png-devel
BuildRequires:	jpeg-devel
BuildRequires:	python-devel
BuildRequires:	pkgconfig(alsa)
BuildRequires:	libjack-devel
BuildRequires:	pulseaudio-devel
BuildRequires:	fluidsynth-devel
BuildRequires:	liblo-devel
BuildRequires:	dssi-devel
BuildRequires:	lua5.2-devel
BuildRequires:	luajit-devel
BuildRequires:	portaudio-devel
BuildRequires:	fltk-devel
%if %{build_java}
BuildRequires:	java-devel
BuildRequires:	jpackage-utils
%endif
BuildRequires:	libxslt-devel
BuildRequires:	libvorbis-devel
BuildRequires:	libogg-devel
BuildRequires:	gettext
BuildRequires:	gcc-c++
BuildRequires:	boost-devel
BuildRequires:	bison
BuildRequires:	flex
BuildRequires:	docbook-style-xsl
BuildRequires:	xsltproc

Obsoletes:	csound-tutorial <= 5.08
Obsoletes:	olpcsound <= 5.10.90
Obsoletes:	csound-java < 5.19.01-10
Obsoletes:	csound-javadoc < 5.19.01-10

# The fltk and tcl/tk frontends were removed in version 6 of csound.  These
# obsoletes can be removed in Mageia 7.
Obsoletes: %{name}-gui < 6.0-1
Provides:  %{name}-gui = 6.0-1
Obsoletes: %{name}-tk  < 6.0-1
Provides:  %{name}-tk  = 6.0-1

%global luaver %(lua -v | sed -r 's/Lua ([[:digit:]]+\\.[[:digit:]]+).*/\\1/')

%description
Csound is a sound and music synthesis system, providing facilities for
composition and performance over a wide range of platforms. It is not
restricted to any style of music, having been used for many years in
at least classical, pop, techno, ambient...

%package	devel
Summary:	Csound development files and libraries
Group:		Development/C
Requires:	%{name} = %{version}-%{release}
Obsoletes:	olpcsound-devel <= 5.10.90
Conflicts:	%{name}-python < 5.13.0-3

%description	devel
Contains headers and libraries for developing applications that use Csound.

%package	python
Summary:	Python Csound development files and libraries
Group:		Development/Python
Requires:	%{name} = %{version}-%{release}
Requires:	python

%description	python
Contains Python language bindings for developing Python applications that
use Csound.

%if %{build_java}
%package	java
Summary:	Java Csound support
Group:		Development/Java
Requires:	%{name} = %{version}-%{release}
Requires:	java-headless
Requires:	jpackage-utils

%description	java
Contains Java language bindings for developing and running Java
applications that use Csound.

%package	javadoc
Summary:	API documentation for Java Csound support
Group:		Development/Java

%description	javadoc
API documentation for the %{name}-java package.
%endif

%if 0%{?has_luajit}
%package lua
Summary: Lua Csound support
Requires: %{name} = %{version}-%{release}

%description lua
Contains Lua language bindings for developing and running Lua
applications that use Csound.
%endif

%package	fltk
Summary:	FLTK plugins for Csound
Group:		Sound/Utilities
Requires:	%{name} = %{version}-%{release}
Requires:	fltk

%description	fltk
Contains FLTK plugins for csound

%package	jack
Summary:	Jack Audio plugins for Csound
Group:		Sound/Utilities
Requires:	%{name} = %{version}-%{release}
Requires:	jackit

%description	jack
Contains Jack Audio plugins for Csound

%package	fluidsynth
Summary:	Fluidsyth soundfont plugin for Csound
Group:		Sound/Utilities
Requires:	%{name} = %{version}-%{release}

%description	fluidsynth
Contains Fluidsynth soundfont plugin for Csound.

%package	dssi
Summary:	Disposable Soft Synth Interface (DSSI) plugin for Csound
Group:		Sound/Utilities
Requires:	%{name} = %{version}-%{release}
Requires:	dssi

%description	dssi
Disposable Soft Synth Interface (DSSI) plugin for Csound

%package	osc
Summary:	Open Sound Control (OSC) plugin for Csound
Group:		Sound/Utilities
Requires:	%{name} = %{version}-%{release}

%description	osc
Open Sound Control (OSC) plugin for Csound

%package portaudio
Summary: PortAudio plugin for Csound
Requires: %{name} = %{version}-%{release}

%description portaudio
PortAudio plugin for Csound

%package	virtual-keyboard
Summary:	Virtual MIDI keyboard plugin for Csound
Group:		Sound/Utilities
Requires:	%{name} = %{version}-%{release}
Requires:	fltk

%description	virtual-keyboard
A virtual MIDI keyboard plugin for Csound

%package	doc
Summary:	Csound manual
Group:		Documentation
Obsoletes:	%{name}-manual
Requires:	%{name} = %{version}-%{release}
BuildArch:	noarch

%description	doc
Canonical Reference Manual for Csound.


%prep
%setup -q -n Csound%{version}
%setup -q -n Csound%{version} -T -D -a 2

%patch0 -p1 -b .64-bit-plugin-path
%patch1 -p1 -b .fix-conflicts
%patch2 -b .default-pulse
%ifnarch x86_64
%patch3 -p1 -b .sse2
%endif
%patch4 -p1 -b .porttime
%patch5 -b .xdg-open
%patch6 -p1 -b .orc
%patch7 -p1 -b .boost

# Fix python, lua, and java install paths
sed -e 's,\(set(PYTHON_MODULE_INSTALL_DIR \).*,\1"%{python_sitearch}"),' \
    -e 's,\(set(JAVA_MODULE_INSTALL_DIR.*\)),\1/csound/java),' \
    -e 's,\(set(LUA_MODULE_INSTALL_DIR.*\)),\1/lua/%{luaver}),' \
    -i CMakeLists.txt

# PYTHON_MODULE_INSTALL_DIR was changed to execute_process.
perl -p -0777 -i -e 's#execute_process\s*\(.*?OUTPUT_VARIABLE (PYTHON_MODULE_INSTALL_DIR)\s*?\)\s*\n#set($1 "%{python_sitearch}")\n#ms' CMakeLists.txt

# Fix end of line encodings
%define fix_line_encoding() \
  sed -i.orig 's/\\r\\n/\\n/;s/\\r/\\n/g' %1; \
  touch -r %1.orig %1; \
  rm -f %1.orig;

for csd in $(find manual6/examples -name \*.csd); do
  %fix_line_encoding $csd
done
%fix_line_encoding examples/c/pvsbus.csd
%fix_line_encoding examples/cplusplus/fl_controller.dev
%fix_line_encoding examples/csoundapi_tilde/csoundapi-osx.pd
%fix_line_encoding examples/lua/csound_ffi.lua
%fix_line_encoding examples/opcode_demos/band.csd
%fix_line_encoding examples/opcode_demos/sdft.csd
%fix_line_encoding manual6/examples/128,8-torus
%fix_line_encoding manual6/examples/128-spiral-8,16,128,2,1over2
%fix_line_encoding manual6/examples/128-stringcircular
%fix_line_encoding manual6/examples/string-128.matrix

# Fix spurious executable bits
chmod a-x examples/csoundapi_tilde/csoundapi-osx.pd \
          examples/csoundapi_tilde/csoundapi.pd \
          examples/lua/lua_example.lua \
          manual6/examples/128*
%build
if [ "%{_libdir}" = "%{_prefix}/lib64" ]; then
  %cmake -DUSE_LIB64:BOOL=ON
else
  %cmake -DUSE_LIB64:BOOL=OFF
fi

make %{?_smp_mflags} V=1

%if %{build_java}
# Generate javadoc
(cd interfaces; mkdir apidocs; javadoc -d apidocs *.java)
%endif

# Make the manual
(
    cd ../
    make -C manual6 html-dist \
      XSL_BASE_PATH=%{_datadir}/sgml/docbook/xsl-stylesheets
)

%install
pushd build
%make_install

%if %{build_java}

# Fix the Java installation
install -dm 755 %{buildroot}%{_javadir}
(cd %{buildroot}%{_javadir}; ln -s %{_libdir}/%{name}/java/csnd.jar .)
mv %{buildroot}%{_libdir}/%{name}/java/lib_jcsound6.so %{buildroot}%{_libdir}

# Install Javadocs
install -dm 755 %{buildroot}%{_javadocdir}
cp -a interfaces/apidocs %{buildroot}%{_javadocdir}/%{name}-java

%endif

popd

%find_lang %{name}6

%files -f %{name}6.lang
%doc COPYING ChangeLog README.md
%{_bindir}/atsa
%{_bindir}/cs
%{_bindir}/csanalyze
%{_bindir}/csb64enc
%{_bindir}/csbeats
%{_bindir}/csdebugger
%{_bindir}/csound
%{_bindir}/cvanal
%{_bindir}/dnoise
%{_bindir}/cs-envext
%{_bindir}/cs-extract
%{_bindir}/cs-extractor
%{_bindir}/het_export
%{_bindir}/het_import
%{_bindir}/hetro
%{_bindir}/lpanal
%{_bindir}/lpc_export
%{_bindir}/lpc_import
%{_bindir}/makecsd
%{_bindir}/cs-mixer
%{_bindir}/pvanal
%{_bindir}/pvlook
%{_bindir}/cs-scale
%{_bindir}/cs-scot
%{_bindir}/cs-src_conv
%{_bindir}/scsort
%{_bindir}/sdif2ad
%{_bindir}/cs-sndinfo
%{_bindir}/cs-srconv
%{_bindir}/pv_export
%{_bindir}/pv_import
%{_libdir}/lib%{name}64.so.6.0
%{_libdir}/libcsnd6.so.6.0
%dir %{_libdir}/%{name}/plugins-6.0
%{_libdir}/%{name}/plugins-6.0/csladspa.so
%{_libdir}/%{name}/plugins-6.0/libampmidid.so
%{_libdir}/%{name}/plugins-6.0/libbuchla.so
%{_libdir}/%{name}/plugins-6.0/libcellular.so
%{_libdir}/%{name}/plugins-6.0/libcontrol.so
%{_libdir}/%{name}/plugins-6.0/libchua.so
%{_libdir}/%{name}/plugins-6.0/libcs_date.so
%{_libdir}/%{name}/plugins-6.0/libdoppler.so
%{_libdir}/%{name}/plugins-6.0/libexciter.so
%{_libdir}/%{name}/plugins-6.0/libframebuffer.so
%{_libdir}/%{name}/plugins-6.0/libfareygen.so
%{_libdir}/%{name}/plugins-6.0/libfractalnoise.so
%{_libdir}/%{name}/plugins-6.0/libimage.so
%{_libdir}/%{name}/plugins-6.0/libipmidi.so
%{_libdir}/%{name}/plugins-6.0/libjacko.so
%{_libdir}/%{name}/plugins-6.0/libjoystick.so
%{_libdir}/%{name}/plugins-6.0/libmixer.so
#%%{_libdir}/%%{name}/plugins/liboggplay.so
%{_libdir}/%{name}/plugins-6.0/libpadsynth.so
%{_libdir}/%{name}/plugins-6.0/libplaterev.so
%{_libdir}/%{name}/plugins-6.0/libpy.so
%{_libdir}/%{name}/plugins-6.0/librtalsa.so
%{_libdir}/%{name}/plugins-6.0/librtpulse.so
%{_libdir}/%{name}/plugins-6.0/libscansyn.so
%{_libdir}/%{name}/plugins-6.0/libserial.so
%{_libdir}/%{name}/plugins-6.0/libsignalflowgraph.so
%{_libdir}/%{name}/plugins-6.0/libstdutil.so
%{_libdir}/%{name}/plugins-6.0/libsystem_call.so
%{_libdir}/%{name}/plugins-6.0/liburandom.so

%files devel
%{_includedir}/%{name}/
%{_libdir}/lib%{name}64.so
%{_libdir}/libcsnd6.so

%files python
%{python2_sitearch}/*

%if %{build_java}
%files java
%{_libdir}/lib_jcsound.so
%{_libdir}/%{name}/java/
%{_javadir}/csnd.jar

%files javadoc
%{_javadocdir}/%{name}-java
%endif

%if 0%{?has_luajit}
%files lua
%{_libdir}/%{name}/plugins-6.0/libLuaCsound.so
%{_libdir}/lua/%{luaver}/*
%endif

%files fltk
%{_libdir}/%{name}/plugins-6.0/libwidgets.so

%files jack
%{_libdir}/%{name}/plugins-6.0/librtjack.so
%{_libdir}/%{name}/plugins-6.0/libjackTransport.so

%files fluidsynth
%{_libdir}/%{name}/plugins-6.0/libfluidOpcodes.so

%files dssi
%{_libdir}/%{name}/plugins-6.0/libdssi4cs.so

%files osc
%{_libdir}/%{name}/plugins-6.0/libosc.so

%files portaudio
%{_libdir}/%{name}/plugins-6.0/librtpa.so

%files virtual-keyboard
%{_libdir}/%{name}/plugins-6.0/libvirtual.so

%files doc
%doc manual6/copying.txt
%doc manual6/html/*
%doc examples/*


%changelog
* Wed Mar 01 2017 ghibo <ghibo> 6.06-4.mga6
+ Revision: 1088343
- Rebuilt against pulseaudio 10

* Fri Mar 11 2016 blino <blino> 6.06-3.mga6
+ Revision: 988886
- fix build with latest boost (patches from upstream)

  + umeabot <umeabot>
    - Mageia 6 Mass Rebuild

* Sat Oct 10 2015 shlomif <shlomif> 6.06-1.mga6
+ Revision: 889172
- Add missing BR
- Add missing BR
- Fixes for the patching
- New version 6.06 - used the Fedora .spec as reference-thx.

  + daviddavid <daviddavid>
    - rebuild for new tcl/tk 8.6.4
    - fix python2 macros (fix build)

* Sun Aug 16 2015 fwang <fwang> 5.19.01-11.mga6
+ Revision: 865072
- rebuild for new fltk

* Sun Nov 30 2014 sander85 <sander85> 5.19.01-10.mga5
+ Revision: 800046
- Disable java

* Wed Oct 15 2014 umeabot <umeabot> 5.19.01-9.mga5
+ Revision: 750291
- Second Mageia 5 Mass Rebuild

* Sat Sep 27 2014 tv <tv> 5.19.01-8.mga5
+ Revision: 726066
- rebuild for missing pythoneggs deps

* Wed Sep 24 2014 wally <wally> 5.19.01-7.mga5
+ Revision: 724218
- exclude %%_docdir from auto-requires

* Thu Sep 18 2014 umeabot <umeabot> 5.19.01-6.mga5
+ Revision: 693703
- Rebuild to fix library dependencies

* Tue Sep 16 2014 umeabot <umeabot> 5.19.01-5.mga5
+ Revision: 678604
- Mageia 5 Mass Rebuild

* Tue Aug 19 2014 luigiwalser <luigiwalser> 5.19.01-4.mga5
+ Revision: 665342
- drop gcj support (from fedora)

  + pterjan <pterjan>
    - Rebuild for new Python

* Mon Oct 21 2013 umeabot <umeabot> 5.19.01-2.mga4
+ Revision: 539489
- Mageia 4 Mass Rebuild

* Sun Oct 06 2013 shlomif <shlomif> 5.19.01-1.mga4
+ Revision: 492285
- New version 5.19.01 - some updates to SPEC from Fedora

* Tue Jul 09 2013 fwang <fwang> 5.17.11-5.mga4
+ Revision: 451718
- rebuild for new boost

* Mon Jun 03 2013 fwang <fwang> 5.17.11-4.mga4
+ Revision: 435807
- rebuild for new libpng

* Fri Jan 11 2013 umeabot <umeabot> 5.17.11-3.mga3
+ Revision: 348368
- Mass Rebuild - https://wiki.mageia.org/en/Feature:Mageia3MassRebuild

* Thu Nov 29 2012 malo <malo> 5.17.11-2.mga3
+ Revision: 322797
- update RPM group

* Mon Aug 06 2012 sander85 <sander85> 5.17.11-1.mga3
+ Revision: 279254
- New version: 5.17.11.
- Rediff patches 1,4,6,8 and 10.
- Drop patches 11-14.
- Fix build with bison 2.6.
- Switch BR to lua5.1-devel.
- Fill doc package.

* Tue Apr 24 2012 fwang <fwang> 5.13.0-7.mga2
+ Revision: 233147
- add patch fixing CVE-2012-210[678]
- drop linkflaggs
- try build with ldflags

* Sat Apr 07 2012 fwang <fwang> 5.13.0-5.mga2
+ Revision: 229474
- fix typo
- add upstream patch to fix CVE-2012-0270: two buffer overflow flaws in getnum()

* Mon Sep 19 2011 fwang <fwang> 5.13.0-4.mga2
+ Revision: 145280
- rebuild for new libpng

* Mon Jul 11 2011 ahmad <ahmad> 5.13.0-3.mga2
+ Revision: 122089
- Move libcsnd.so to the -devel package

* Mon Jul 11 2011 fwang <fwang> 5.13.0-2.mga2
+ Revision: 122088
- rebuild for new fltk

* Sun Jul 10 2011 ahmad <ahmad> 5.13.0-1.mga2
+ Revision: 121758
- Update the manual sources (from the Fedora src.rpm)
- Update to 5.13.0
- Rediff patch0,1,2,4,6,7,10
- Drop patch9, fixed upstream
- Add BR flex, bison
- Update the file list

* Sun Jul 03 2011 fwang <fwang> 5.11-8.mga2
+ Revision: 117572
- we use 8.5 now by default
- rebuild for new csound

* Sun Feb 20 2011 eandry <eandry> 5.11-7.mga1
+ Revision: 54675
- drop buildroot
- bump release for upgrade
- imported package csound


* Sun Nov 07 2010 Jani Välimaa <wally@mandriva.org> 5.11-6mdv2011.0
+ Revision: 594452
- recognize python 2.7
- rebuild for python 2.7

* Sat Jan 16 2010 Funda Wang <fwang@mandriva.org> 5.11-5mdv2010.1
+ Revision: 492228
- rebuild for new libjpegv8

* Fri Jan 08 2010 Frederik Himpe <fhimpe@mandriva.org> 5.11-4mdv2010.1
+ Revision: 487725
- rebuild

* Sun Jan 03 2010 Emmanuel Andry <eandry@mandriva.org> 5.11-3mdv2010.1
+ Revision: 486025
- rebuild for new fltk

* Thu Nov 26 2009 Jérôme Brenier <incubusss@mandriva.org> 5.11-2mdv2010.1
+ Revision: 470418
-jack subpackage : requires jackit instead of jack-audio-connection-kit

* Sat Nov 07 2009 Frederik Himpe <fhimpe@mandriva.org> 5.11-1mdv2010.1
+ Revision: 462689
- update to new version 5.11

* Thu Oct 08 2009 Guillaume Rousse <guillomovitch@mandriva.org> 5.10.1-3mdv2010.0
+ Revision: 456003
- fix groups
- rename -manual subpackage to -doc
- don't make it noarch, it doesn't work

* Sun Sep 20 2009 Nicolas Lécureuil <nlecureuil@mandriva.com> 5.10.1-2mdv2010.0
+ Revision: 446059
- Fix groups
- Fix obsoletes
- Let my "monk" packaging habits fix my spec files :)
- Fix file list
- import csound

